@@ -60,7 +60,7 @@ def main(prog='fastgplearn', description='fastgplearn command line tool.', args=
             help=short,
             description=long)
         cmd.add_arguments(subparser)
-        functions[command] = cmd.run_gp
+        functions[command] = cmd.run
         parsers[command] = subparser
 
     args = parser.parse_args(args)
